@@ -21,9 +21,9 @@ from evenage import __version__ as pkg_version
 from evenage.core import (
     AgentRunner,
     BackendFactory,
-    EvenAgeConfig,
     run_agent,
 )
+from evenage.core.config import load_runtime_config, EvenAgeConfig
 from fastapi import FastAPI, HTTPException, WebSocket, WebSocketDisconnect
 from fastapi.middleware.cors import CORSMiddleware
 from pydantic import BaseModel
@@ -80,8 +80,8 @@ async def lifespan(app: FastAPI):
     """Initialize and cleanup services."""
     global config, factory, database, message_bus
 
-    # Load configuration
-    config = EvenAgeConfig()
+    # Load configuration (prefer project .evenage/config.json)
+    config = load_runtime_config()
     factory = BackendFactory(config)
 
     # Initialize services
