@@ -34,7 +34,7 @@ def add():
 @click.option("--goal", help="Agent goal")
 @click.option("--backstory", help="Agent backstory")
 @click.option("--llm-provider", default="gemini", help="LLM provider")
-@click.option("--llm-model", default="gemini-2.0-flash-exp", help="LLM model")
+@click.option("--llm-model", default="gemini-2.5-flash", help="LLM model")
 def add_agent(
     agent_name: str,
     role: str | None,
@@ -49,6 +49,19 @@ def add_agent(
         evenage add agent summarizer
         evenage add agent analyst --role "Data Analyst" --goal "Analyze data"
     """
+    # Validate agent name
+    if "-" in agent_name:
+        raise click.BadParameter(
+            "Agent name cannot contain hyphens (-). Use underscores (_) instead.",
+            param_hint="agent_name"
+        )
+    
+    if not agent_name.replace("_", "").isalnum():
+        raise click.BadParameter(
+            "Agent name must contain only letters, numbers, and underscores.",
+            param_hint="agent_name"
+        )
+    
     # Ensure we're in a project
     if not validate_project_directory(Path.cwd()):
         raise ProjectNotFoundError()
@@ -94,6 +107,19 @@ def add_tool(
         evenage add tool calculator
         evenage add tool scraper --agent researcher
     """
+    # Validate tool name
+    if "-" in tool_name:
+        raise click.BadParameter(
+            "Tool name cannot contain hyphens (-). Use underscores (_) instead.",
+            param_hint="tool_name"
+        )
+    
+    if not tool_name.replace("_", "").isalnum():
+        raise click.BadParameter(
+            "Tool name must contain only letters, numbers, and underscores.",
+            param_hint="tool_name"
+        )
+    
     # Ensure we're in a project
     if not validate_project_directory(Path.cwd()):
         raise ProjectNotFoundError()
@@ -173,10 +199,10 @@ def _create_agent_files(
     handler_context = {
         "agent_name": agent_name,
         "agent_class": f"{agent_name.capitalize()}Agent",
-        "agent_role": role,
-        "agent_goal": goal,
-        "agent_backstory": backstory or "",
-        "agent_description": role,
+        "role": role,
+        "goal": goal,
+        "backstory": backstory or "",
+        "description": role,
         "allow_delegation": False,
         "max_iterations": 15,
         "tools": [],
@@ -191,8 +217,8 @@ def _create_agent_files(
     worker_context = {
         "agent_name": agent_name,
         "agent_class": f"{agent_name.capitalize()}Agent",
-        "agent_role": role,
-        "agent_goal": goal,
+        "role": role,
+        "goal": goal,
     }
     renderer.render_to_file(
         "agent_worker.py.j2",
@@ -240,10 +266,11 @@ def _auto_register_agent(agent_name: str, role: str, goal: str, backstory: str |
     try:
         import asyncio
 
-        from evenage.core import BackendFactory, EvenAgeConfig
+        from evenage.core import BackendFactory
+        from evenage.core.config import load_runtime_config
 
         # Try to connect to Redis
-        config = EvenAgeConfig()
+        config = load_runtime_config()
         factory = BackendFactory(config)
 
         async def register():
