@@ -1,12 +1,77 @@
 """
+EvenAge v3 lightweight config helpers.
+
+This module exposes helpers to construct bus, storage, tracer, and to
+resolve agents dynamically from the 'agents' package if present.
+"""
+
+from __future__ import annotations
+
+import importlib
+from typing import Dict, Any
+import os
+
+from .tracing import TraceLogger, NoopTracer
+from .factory import BackendFactory
+
+
+def get_bus():
+    # Build bus via BackendFactory honoring runtime config
+    try:
+        cfg = load_runtime_config()
+    except Exception:
+        from .config import EvenAgeConfig
+        cfg = EvenAgeConfig()
+    return BackendFactory(cfg).create_queue_backend()
+
+
+def get_storage():
+    # Return configured storage backend (MinIO or in-memory)
+    try:
+        cfg = load_runtime_config()
+    except Exception:
+        from .config import EvenAgeConfig
+        cfg = EvenAgeConfig()
+    return BackendFactory(cfg).create_storage_backend()
+
+
+def get_tracer():
+    db_url = os.environ.get("DATABASE_URL")
+    if db_url:
+        return TraceLogger(db_url)
+    return NoopTracer()
+
+
+def load_agents() -> Dict[str, Any]:
+    """Load agent classes dynamically from 'agents.<name>.handler'.
+
+    Expects each handler to expose a class named <Name>Agent with a default constructor.
+    If absent, skips that agent.
+    """
+    discovered: Dict[str, Any] = {}
+    try:
+        agents_pkg = importlib.import_module("agents")
+        import pkgutil
+
+        for m in pkgutil.iter_modules(agents_pkg.__path__):
+            name = m.name
+            try:
+                mod = importlib.import_module(f"agents.{name}.handler")
+                cls_name = f"{name.capitalize()}Agent"
+                AgentCls = getattr(mod, cls_name)
+                discovered[name] = AgentCls()  # type: ignore[call-arg]
+            except Exception:
+                continue
+    except Exception:
+        pass
+    return discovered
+"""
 Configuration management for EvenAge.
 
 Provides pluggable backend configuration via environment and YAML.
 All integrations (queue, database, vector, LLM, cache) are configurable.
 """
 
-from __future__ import annotations
-
 from pathlib import Path
 from typing import Any, Protocol
 
@@ -50,7 +115,8 @@ class EvenAgeConfig(BaseSettings):
     # Kafka (optional)
     kafka_bootstrap: str | None = Field(default=None, description="Kafka bootstrap servers (host:port)")
 
-    # MinIO/S3 Storage (optional, for large artifacts)
+    # Storage selection and MinIO/S3 settings
+    storage_backend: str = Field(default="minio", description="Storage backend: minio | local")
     minio_endpoint: str = Field(default="localhost:9000", description="MinIO endpoint")
     minio_access_key: str = Field(default="minioadmin", description="MinIO access key")
     minio_secret_key: str = Field(
@@ -216,15 +282,15 @@ class BackendFactory:
     def create_queue_backend(self) -> QueueBackend:
         """Create message queue backend based on config."""
         if self.config.queue_backend == "redis":
-            from .message_bus import RedisBus
+            from .backends.queue import RedisBus
             bus = RedisBus(self.config.redis_url)
         elif self.config.queue_backend == "memory":
-            from .message_bus import MemoryBus
+            from .backends.queue import MemoryBus
             if BackendFactory._memory_bus_singleton is None:
                 BackendFactory._memory_bus_singleton = MemoryBus()
             bus = BackendFactory._memory_bus_singleton
         elif self.config.queue_backend == "kafka":
-            from .message_bus import KafkaBus
+            from .backends.queue import KafkaBus
             if not self.config.kafka_bootstrap:
                 raise ValueError("kafka_bootstrap is required for kafka queue_backend")
             bus = KafkaBus(self.config.kafka_bootstrap)
@@ -246,16 +312,16 @@ class BackendFactory:
 
     def create_database_backend(self) -> DatabaseBackend:
         """Create database backend based on config."""
-        from .database import DatabaseService
+        from .backends.database import DatabaseService
         return DatabaseService(self.config.database_url)
 
     def create_vector_backend(self) -> VectorBackend:
         """Create vector store backend based on config."""
         if self.config.vector_backend == "local":
-            from .vector import LocalVectorStore
+            from .backends.vector import LocalVectorStore
             return LocalVectorStore()
         if self.config.vector_backend == "pgvector":
-            from .vector import PostgresVectorStore
+            from .backends.vector import PostgresVectorStore
             return PostgresVectorStore(self.config.database_url)
         raise ValueError(f"Unknown vector_backend: {self.config.vector_backend}")
 
@@ -297,8 +363,8 @@ class BackendFactory:
 
     def create_storage_backend(self):
         """Create storage backend for artifacts (MinIO/S3)."""
-        if self.config.minio_endpoint:
-            from .storage import MinIOStorage
+        if self.config.storage_backend == "minio" and self.config.minio_endpoint:
+            from .backends.storage import MinIOStorage
             return MinIOStorage(
                 endpoint=self.config.minio_endpoint,
                 access_key=self.config.minio_access_key,
@@ -306,10 +372,83 @@ class BackendFactory:
                 secure=self.config.minio_secure
             )
         # Fall back to in-memory storage if no MinIO configured
-        from .storage import InMemoryStorage
+        from .backends.storage import InMemoryStorage
         return InMemoryStorage()
 
 
+# --- Runtime config loader (JSON-driven) ---
+
+def _find_project_root(start: Path | None = None) -> Path | None:
+    """Locate project root by looking for evenage.yml or .evenage/ directory."""
+    current = start or Path.cwd()
+    for directory in [current, *current.parents]:
+        if (directory / "evenage.yml").exists() or (directory / ".evenage").exists():
+            return directory
+    return None
+
+
+def load_runtime_config() -> EvenAgeConfig:
+    """Load EvenAgeConfig, honoring .evenage/config.json when present.
+
+    Rules:
+    - If .evenage/config.json exists, map its fields to EvenAgeConfig overrides
+    - If enable_scaling is false (or absent), default to local lightweight mode:
+        queue_backend=memory, db_backend=sqlite, database_url=sqlite:///./evenage.db, storage_backend=local
+    - If enable_scaling is true, use selected backends with sensible defaults if URLs missing
+    - Environment variables (via BaseSettings) still apply as base; JSON overrides take precedence
+    """
+    base = EvenAgeConfig()  # load from env/.env
+
+    root = _find_project_root()
+    if not root:
+        return base
+
+    json_path = root / ".evenage" / "config.json"
+    if not json_path.exists():
+        return base
+
+    try:
+        import json
+        data = json.loads(json_path.read_text(encoding="utf-8"))
+    except Exception:
+        return base
+
+    enable_scaling = bool(data.get("enable_scaling", False))
+    queue_backend = data.get("queue_backend") or ("redis" if enable_scaling else "memory")
+    db_backend = data.get("db_backend") or ("postgres" if enable_scaling else "sqlite")
+    storage_backend = data.get("storage_backend") or ("minio" if enable_scaling else "local")
+
+    overrides: dict[str, Any] = {
+        "queue_backend": queue_backend,
+        "db_backend": db_backend,
+        "storage_backend": storage_backend,
+    }
+
+    # URLs / endpoints
+    if db_backend == "sqlite":
+        overrides["database_url"] = "sqlite:///./evenage.db"
+    elif db_backend == "postgres" and not getattr(base, "database_url", None):
+        overrides["database_url"] = "postgresql://evenage:evenage@localhost:5432/evenage"
+
+    if queue_backend == "redis" and not getattr(base, "redis_url", None):
+        overrides["redis_url"] = "redis://localhost:6379"
+
+    if storage_backend == "minio":
+        # Use defaults unless already set via env
+        if not getattr(base, "minio_endpoint", None):
+            overrides["minio_endpoint"] = "localhost:9000"
+        overrides.setdefault("minio_access_key", base.minio_access_key)
+        overrides.setdefault("minio_secret_key", base.minio_secret_key)
+        overrides.setdefault("minio_secure", base.minio_secure)
+    else:
+        # Local storage: disable minio usage
+        overrides["minio_endpoint"] = ""
+
+    # Vector/LLM/cache remain as in env unless we choose to derive them later
+
+    return EvenAgeConfig(**{**base.model_dump(), **overrides})
+
+
 
 class ProjectConfig(BaseModel):
     """
@@ -406,55 +545,26 @@ def connect_infrastructure(config: EvenAgeConfig):
     bus, database, vector, llm, storage, cache
     """
     from evenage.infra import Infra
-    from evenage.infra.database import connect_database
-    from evenage.infra.llm_client import connect_llm
-    from evenage.infra.message_bus import connect_bus
-    from evenage.infra.storage import connect_storage
-    from evenage.infra.vector_store import connect_vector_store
 
-    database = connect_database(config.database_url)
+    factory = BackendFactory(config)
 
-    storage = connect_storage(
-        endpoint=config.minio_endpoint,
-        access_key=config.minio_access_key,
-        secret_key=config.minio_secret_key,
-        secure=config.minio_secure,
-        fallback_inmemory=True,
-    )
+    # Core backends
+    bus = factory.create_queue_backend()
+    database = factory.create_database_backend()
+    storage = factory.create_storage_backend()
 
-    bus = connect_bus(
-        config.queue_backend,
-        redis_url=config.redis_url if config.queue_backend == "redis" else None,
-        kafka_bootstrap=config.kafka_bootstrap if config.queue_backend == "kafka" else None,
-        storage=storage if config.enable_large_response_storage else None,
-        storage_bucket=config.minio_bucket if config.enable_large_response_storage else None,
-        storage_threshold_kb=(config.storage_threshold_kb if config.enable_large_response_storage else None),
-    )
-
-    vector = None
+    # Optional backends
     try:
-        vector = connect_vector_store(
-            config.vector_backend,
-            database_url=(config.database_url if config.vector_backend == "pgvector" else None),
-        )
+        vector = factory.create_vector_backend()
     except Exception:
         vector = None
 
-    llm = None
     try:
-        llm = connect_llm(
-            config.llm_backend,
-            model=config.llm_model,
-            openai_api_key=config.openai_api_key,
-            openai_base_url=config.openai_base_url,
-            anthropic_api_key=config.anthropic_api_key,
-            gemini_api_key=config.gemini_api_key,
-            http_endpoint=config.http_llm_endpoint,
-        )
+        llm = factory.create_llm_backend()
     except Exception:
         llm = None
 
-    cache = BackendFactory(config).create_cache_backend()
+    cache = factory.create_cache_backend()
 
     return Infra(
         bus=bus,
@@ -465,3 +575,4 @@ def connect_infrastructure(config: EvenAgeConfig):
         cache=cache,
     )
 
+
