@@ -14,7 +14,7 @@ from contextlib import suppress
 import time
 import uuid
 
-from .agent_runtime import Agent
+from .agent import Agent
 from .config import AgentConfig, BackendFactory, EvenAgeConfig
 
 
@@ -69,19 +69,21 @@ class AgentRunner:
         """
         # Determine agent
         if agent_name:
-            # Load agent class dynamically, with fallback to test agents path
+            # Load agent class dynamically. Prefer local project agents; fall back to internal test agents only during framework development.
             try:
                 agent_mod = importlib.import_module(f"agents.{agent_name}.handler")
                 AgentClass = getattr(agent_mod, f"{agent_name.capitalize()}Agent")
-            except (ModuleNotFoundError, AttributeError):
+            except (ModuleNotFoundError, AttributeError) as primary_err:
+                # Optional fallback for EvenAge repo development (not user projects)
                 try:
                     agent_mod = importlib.import_module(f"evenage.tests.agents.{agent_name}.handler")
                     AgentClass = getattr(agent_mod, f"{agent_name.capitalize()}Agent")
-                except (ModuleNotFoundError, AttributeError) as e:
+                except Exception:
+                    # Hide internal fallback path from user-facing error to avoid confusion
                     raise ValueError(
                         f"Could not load agent '{agent_name}'. "
-                        f"Make sure agents/{agent_name}/handler.py exists and defines {agent_name.capitalize()}Agent class. "
-                        f"Error: {e}"
+                        f"Ensure 'agents/{agent_name}/handler.py' exists and defines '{agent_name.capitalize()}Agent'. "
+                        f"Root cause: {primary_err}"
                     )
 
             # Get agent config from the class decorator metadata
@@ -199,6 +201,10 @@ class AgentRunner:
 
     def _start_inline_workers(self, agent_names: list[str]) -> None:
         """Start a background task that consumes tasks and runs target agents inline."""
+        import logging
+        logger = logging.getLogger(__name__)
+        logger.info(f"Starting inline workers for agents: {agent_names}")
+        
         stop = asyncio.Event()
         self._inline_worker_stop = stop
 
@@ -206,20 +212,24 @@ class AgentRunner:
             # Cache agent instances per name to avoid re-import overhead
             agent_cache: dict[str, Agent] = {}
             bus = self.factory.create_queue_backend()
+            logger.info(f"Inline worker loop started, listening for tasks...")
             while not stop.is_set():
                 progress = False
                 for name in agent_names:
                     try:
                         tasks = await bus.consume_tasks(name, block_ms=200, count=5)
                     except Exception:
+                        logger.exception(f"Error consuming tasks for {name}")
                         tasks = []
                     if not tasks:
                         continue
+                    logger.info(f"Inline worker received {len(tasks)} task(s) for {name}")
                     progress = True
                     for data in tasks:
                         try:
                             task_id = data.get("task_id")
                             payload = data.get("payload", {})
+                            logger.info(f"Processing task {task_id} for {name}")
                             # Get or create agent instance
                             if name not in agent_cache:
                                 try:
@@ -227,6 +237,7 @@ class AgentRunner:
                                     cls = getattr(mod, f"{name.capitalize()}Agent")
                                 except Exception as e:
                                     # Skip if cannot import
+                                    logger.error(f"Failed to import agent {name}: {e}")
                                     continue
                                 agent_cfg = AgentConfig(
                                     name=getattr(cls, 'AGENT_NAME', name),
@@ -235,16 +246,20 @@ class AgentRunner:
                                 )
                                 inst: Agent = cls(agent_cfg, self.env_config)
                                 await inst.connect_bus()
+                                logger.info(f"Created inline worker agent instance for {name}")
                                 agent_cache[name] = inst
                             inst = agent_cache[name]
                             # Execute task
                             result = await inst.handle(payload)
+                            logger.info(f"Task {task_id} completed: {result.get('status', 'unknown')}")
                             # Publish response for waiter
                             if task_id:
                                 with suppress(Exception):
                                     await bus.publish_response(task_id, result)
+                                logger.info(f"Published response for task {task_id}")
                         except Exception:
                             # On processing error, continue loop
+                            logger.exception(f"Error processing task {data.get('task_id')} for {name}")
                             continue
 
                 # Avoid busy loop if no progress
