@@ -11,7 +11,8 @@ from typing import Any
 
 def connect_database(database_url: str) -> Any:
     """Create and return a DatabaseService for the given URL."""
-    from evenage.core.database import DatabaseService
+    # Moved to unified backends module
+    from evenage.core.backends.database import DatabaseService
 
     db = DatabaseService(database_url)
     # Ensure tables exist
