@@ -21,7 +21,8 @@ def connect_storage(
 
     If endpoint is None and fallback_inmemory=True, returns InMemoryStorage.
     """
-    from evenage.core.storage import InMemoryStorage, MinIOStorage
+    # Use unified backends module
+    from evenage.core.backends.storage import InMemoryStorage, MinIOStorage
 
     if endpoint:
         return MinIOStorage(
