@@ -13,7 +13,8 @@ def connect_vector_store(
     *,
     database_url: str | None = None,
 ) -> Any:
-    from evenage.core.vector import LocalVectorStore, PostgresVectorStore
+    # Use unified backends module
+    from evenage.core.backends.vector import LocalVectorStore, PostgresVectorStore
 
     if backend == "local":
         return LocalVectorStore()
